﻿using System;
using System.Windows.Input;

namespace TopConAPIDotNet4WPFExample.Commands
{
  public class GenericCommand : ICommand
  {
    private readonly Predicate<object> _canExecuteMethod; 
    private readonly Action<object> _executeMethod;

    public GenericCommand(Action<object> executeMethod, Predicate<object> canExecuteMethod = null)
    {
      if(executeMethod == null)
      {
        throw new ArgumentNullException("executeMethod");
      }

      _canExecuteMethod = canExecuteMethod;
      _executeMethod = executeMethod;
    }

    public void Execute(object parameter)
    {
      _executeMethod(parameter);
    }

    public bool CanExecute(object parameter)
    {
      return _canExecuteMethod == null || _canExecuteMethod(parameter);
    }

    public event EventHandler CanExecuteChanged
    {
      add { CommandManager.RequerySuggested += value; }
      remove { CommandManager.RequerySuggested -= value; }
    }
  }
}
