﻿
Imports CH.Regatron.HPPS.Device

Module Module1

  Private NL As String = Environment.NewLine
  Private SPACE1 As String = "    "
  Private SPACE2 As String = SPACE1 + SPACE1

  Sub Main()
    Dim cKey As System.ConsoleKey

    Console.WriteLine("\n==== ====  Regatron Demo Program: TopConAPIVBTest  ==== ====" & NL)

    ' Here is a Small Loop to Allow User to Run the Demo multiple Times.

    DemoTopConCommands()

    Console.Write("Press any key to end this Demo Program")
    cKey = Console.ReadKey.Key

    Console.Clear()

  End Sub


  ''' <summary>Method to Demonstrate various TopCon Commands.</summary>
  Sub DemoTopConCommands()
    Dim iComNr As Integer = 1
    Dim sComNr As String
    Dim sResponse As String
    Dim myTopCon As Ch.Regatron.HPPS.Device.TopCon
    Dim dVoltRef As Double
    Dim quadMode As TopCon.QuadrantMode


    '----------------- Connect -----------------
    ' Create New TopCon Device object.
    Try
      'myTopCon = New Ch.Regatron.HPPS.Device.TopCon(oTopConConfig, TopCon.Broker.Device.DEVICE_1)
      myTopCon = New Ch.Regatron.HPPS.Device.TopCon()
    Catch oException As Exception
      Console.WriteLine("Error. Creating TopCon Device object FAILED!" & NL & oException.Message)
      Return
    End Try

    'Prompt User for COM Interface Number to be used for the connection to the TopCon Device.
    Console.Write(NL & "Enter COM interface Number to be used [e.g. 1 --> COM1]:")
    sResponse = Console.ReadLine()

    'User has chosen to use the Default value of "1" for COM1.
    If (Len(sResponse) = 0) Then
      sResponse = "1"
    End If

    'Test if the User enetered a False value, then assign a value of 1.
    If (IsNumeric(sResponse)) Then
      iComNr = Convert.ToInt32(sResponse)
    Else
      iComNr = 1
    End If

    'Display the COM Nr being used.
    sComNr = Convert.ToString(iComNr)
    Console.WriteLine("...using COM interface Nr: [" & sComNr & "] " & NL)

    'Open communication channel with the TopCon Device.
    Try
      myTopCon.Connect(iComNr)
    Catch oException As Exception
      Console.WriteLine("Error. Connection to TopCon Device FAILED! Com Nr: " & sComNr & "] " & NL & oException.Message)
      Return
    End Try
    '----------------------------------------------


    '----------------- Power ON -----------------
    'Wait for User Response to Power-ON.
    Console.Write(NL & "Press any key to Power-ON TopCon Device:")
    Console.ReadLine()

    'Demonstrate the TopCon SetPowerON command.
     
    Try
      myTopCon.SetPowerOn()
    Catch oException As Exception
      Console.WriteLine("Error. Power-ON command FAILED!" & NL & oException.Message)
    End Try


    'Display TopCon System State Info.
    Display_TopCon_System_State_Info(myTopCon)
    '----------------------------------------------


    '---------- Set Reference Voltage -------------
    'Wait for User Response to Set Voltage.
    Console.Write(NL & "Enter Reference Voltage (default of 120V is used if nothing is entered):")
    sResponse = Console.ReadLine()
    'User has chosen to use the Default value of "120".
    If (Len(sResponse) = 0) Then
      sResponse = "120"
    End If

    'Test if the User entered a Bad value, then assign a Default value.
    If (IsNumeric(sResponse)) Then
      dVoltRef = Convert.ToInt32(sResponse)
    Else
      dVoltRef = 120
    End If

    'Demonstrate the TopCon SetVoltageReference command.
    Try
      myTopCon.SetReferenceVoltage(dVoltRef)
    Catch oException As Exception
      Console.WriteLine("Error. TopCon SetVoltageReference command FAILED!" & NL & oException.Message)
    End Try
    '----------------------------------------------


    '---------- Get Reference Voltage -------------
    'Demonstrate the TopCon GetVoltageReference command.
    dVoltRef = myTopCon.GetReferenceVoltage()
    Console.WriteLine("Reference Voltage: " & dVoltRef.ToString())
    '----------------------------------------------

    '---------- Get Quadrant Mode -------------
    'Demonstrate the TopCon Quadrant Mode property.
    quadMode = myTopCon.SystemQuadrantMode()
    If(quadMode.HasFlag(TopCon.QuadrantMode.Q1)) Then
        Console.WriteLine("Has Q1")
    End If
    If(quadMode.HasFlag(TopCon.QuadrantMode.Q2)) Then
      Console.WriteLine("Has Q2")
    End If
    If(quadMode.HasFlag(TopCon.QuadrantMode.Q3)) Then
      Console.WriteLine("Has Q3")
    End If
    If(quadMode.HasFlag(TopCon.QuadrantMode.Q4)) Then
      Console.WriteLine("Has Q4")
    End If
    '----------------------------------------------

    
    '---------------- Power Off--------------------
    'Wait for User Response to Power-OFF.
    Console.Write(NL & "Press any key to  Power OFF TopCon Device")
    Console.ReadLine()
    'Demonstrate the TopCon SetPowerOFF command.
    Try
      myTopCon.SetPowerOff()
    Catch oException As Exception
      Console.WriteLine("Error. TopCon SetPowerOFF command FAILED!" & NL & oException.Message)
    End Try

    'Display TopCon System State Info.
    Display_TopCon_System_State_Info(myTopCon)
    '----------------------------------------------


    '---------------- Disconnect --------------------
    'Wait for User Response to Disconnect from TopCon Device.
    Console.Write(NL & "Press any key to  DisConnect from TopCon Device")
    Console.ReadLine()

    'Demonstrate the TopCon Disconnect command.
    Try
      myTopCon.Disconnect()
    Catch oException As Exception
      Console.WriteLine("Error. TopCon Disconnect command FAILED!" & NL & oException.Message)
    End Try
    '----------------------------------------------

  End Sub


  ''' <summary>Method to Demonstrate various TopCon Commands.</summary>
  Sub Display_TopCon_System_State_Info(myTopCon As Ch.Regatron.HPPS.Device.TopCon)
    Console.WriteLine(NL & SPACE1 & "--------  TopCon System status  --------")

    'Display TopCon System Power On/Off Info.
    If (myTopCon.IsPowerON()) Then
      Console.WriteLine(SPACE1 & "Power is ON")
    Else
      Console.WriteLine(SPACE1 & "Power is OFF")
    End If


    'Display TopCon System State Code Nr.
    Console.WriteLine(SPACE1 & "System State: [" & myTopCon.GetSystemState() & "]")

    'Display TopCon System State String.
    Console.WriteLine(SPACE1 & "System State string: [" & myTopCon.GetSystemStateAsString() & "]")

    'Display TopCon System State Error Boolean with Text.
    If (myTopCon.IsInErrorState()) Then
      Console.WriteLine(SPACE1 & "System IS in Error state.")
    Else
      Console.WriteLine(SPACE1 & "System is NOT in Error state.")
    End If

  End Sub

End Module

'End Namespace
